The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {RobustVis}


Type: Package
Title: Visualize ROBUST-RCT Risk of Bias Assessments
Version: 0.1.2
Description: Provides functions to visualize ROBUST-RCT assessments, as introduced by Wang et al. (2025) <doi:10.1136/bmj-2024-081199>. Through a two-step workflow (step 1 and step 2), the package generates bar plots and traffic-light plots that match standard Cochrane styles.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Depends: R (≥ 4.1.0)
Imports: dplyr (≥ 1.2.0), ggplot2 (≥ 4.0.2), scales (≥ 1.4.0), tidyr (≥ 1.3.1)
NeedsCompilation: no
Packaged: 2026-09-14 21:20:09 UTC; xiaobanxia
Author: Guang Chen [aut, cre], Fanrong Liang [aut]
Maintainer: Guang Chen <tcm_chen7410@163.com>
Repository: CRAN
Date/Publication: 2026-09-24 14:50:06 UTC

ROBUST-RCT Step 1 Risk of Bias Assessment

Description

A dataset containing the step 1 risk of bias assessment items (Item 1 to Item 5).

Usage

data_step1

Format

A data frame with 19 rows and 6 variables:

Study

Study identifier and publication year.

Item_1

Random sequence generation assessment.

Item_2

Allocation concealment assessment.

Item_3

Blinding of participants and personnel assessment.

Item_4

Blinding of outcome assessment.

Item_5

Additional bias domain assessment.

Details

Abbreviations used for the assessment items:

Data from Li, Q. et al.'s systematic review and meta-analysis on antibiotic use as the primary outcome.

Li, Q., Zhou, Q., Fan, J., Feng, X., Lai, H., Chen, Y., ... & Zeng, L. (2026). Impact of molecular point-of-care testing for respiratory pathogens on antibiotic use and clinical outcomes in acute respiratory tract infections: a systematic review and meta-analysis. EClinicalMedicine, 92.


ROBUST-RCT Step 2 Risk of Bias Assessment

Description

A dataset containing the step 2 risk of bias assessment items (Item 1 to Item 6).

Usage

data_step2

Format

A data frame with 19 rows and 7 variables:

Study

Study identifier and publication year.

Item_1

Random sequence generation assessment.

Item_2

Allocation concealment assessment.

Item_3

Blinding of participants and personnel assessment.

Item_4

Blinding of outcome assessment.

Item_5

Additional bias domain assessment.

Item_6

Outcome data not included in analysis.

Details

Abbreviations used for the assessment items:

Data from Li, Q. et al.'s systematic review and meta-analysis on antibiotic use as the primary outcome.

Li, Q., Zhou, Q., Fan, J., Feng, X., Lai, H., Chen, Y., ... & Zeng, L. (2026). Impact of molecular point-of-care testing for respiratory pathogens on antibiotic use and clinical outcomes in acute respiratory tract infections: a systematic review and meta-analysis. EClinicalMedicine, 92.


Produce a summary risk-of-bias barplot for Step 1 or Step 2 tools

Description

A function to convert risk-of-bias assessment data for Step 1 or Step 2 into tidy data and plot a summary stacked barplot matching the standard Cochrane style with a boxed legend and custom labels.

Usage

rob_bar(data, step = 1, colour = NULL, ...)

Arguments

data

A dataframe containing the study IDs in the first column, followed by item evaluation columns (columns B to F for Step 1, or columns B to G for Step 2).

step

An integer or character specifying the evaluation step, either 1 or 2. Default is 1.

colour

A character vector specifying the colour scheme. Defaults to NULL, which automatically applies standard Cochrane-style colors.

...

Additional arguments to be passed to internal functions.

Value

A ggplot2 risk-of-bias summary barplot figure.

Examples

rob_bar(data_step1, step = 1)
rob_bar(data_step2, step = 2)

Produce traffic-light plots of risk-of-bias assessments

Description

Draw a robvis-style traffic-light grid for step 1 or step 2 assessments. The first column of 'data' contains study labels; the remaining columns map by position to Item 1–5 ('step = 1') or Item 1–6 ('step = 2').

Usage

rob_traffic_light(data, step, colour = NULL, psize = 10)

Arguments

data

A data frame. Column 1 contains study labels. Step 1 requires five assessment columns; step 2 requires six assessment columns.

step

Assessment step, either '1' or '2'.

colour

A character vector of four colours. It may be unnamed (in the documented level order) or named with full labels/abbreviations. Defaults to green, yellow, red, and blue.

psize

Diameter of the traffic-light circles in millimetres.

Value

A 'ggplot2' object.

Examples

rob_traffic_light(data = data_step1, step = 1)
rob_traffic_light(data = data_step2, step = 2)

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.